pub trait Asset:
Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required method
fn content(self: Vc<Self>) -> Vc<AssetContent>
where Self: Sized;
// Provided methods
fn versioned_content(self: Vc<Self>) -> Vc<Box<dyn VersionedContent>>
where Self: Sized { ... }
fn content_hash(
self: Vc<Self>,
salt: Vc<RcStr>,
algorithm: HashAlgorithm,
) -> Vc<Option<RcStr>>
where Self: Sized { ... }
}Expand description
A file or intermediate result containing content as a Rope or a symlink.
This is a supertrait for Source, OutputAsset, and OutputChunk.
Required Methods
Provided Methods
Sourcefn versioned_content(self: Vc<Self>) -> Vc<Box<dyn VersionedContent>>where
Self: Sized,
fn versioned_content(self: Vc<Self>) -> Vc<Box<dyn VersionedContent>>where
Self: Sized,
The content of the Asset alongside its version.
Sourcefn content_hash(
self: Vc<Self>,
salt: Vc<RcStr>,
algorithm: HashAlgorithm,
) -> Vc<Option<RcStr>>where
Self: Sized,
fn content_hash(
self: Vc<Self>,
salt: Vc<RcStr>,
algorithm: HashAlgorithm,
) -> Vc<Option<RcStr>>where
Self: Sized,
Hash of the content of the Asset. If salt is non-empty it is mixed
into the hash in a single pass before the file bytes.