pub enum ChunkingType {
Parallel {
inherit_async: bool,
hoisted: bool,
},
Async,
Isolated {
_ty: ChunkGroupType,
merge_tag: Option<RcStr>,
},
Shared {
inherit_async: bool,
merge_tag: Option<RcStr>,
},
Traced {
mode: TracedMode,
},
}Expand description
Specifies how a chunk interacts with other chunks when building a chunk group
Variants
Parallel
The referenced module is placed in the same chunk group and is loaded in parallel.
Fields
Async
An async loader is placed into the referencing chunk and loads the separate chunk group in which the module is placed.
Isolated
Create a new chunk group in a separate context, merging references with the same tag into a single chunk group. It does not inherit the available modules from the parent.
Create a new chunk group in a separate context, merging references with the same tag into a single chunk group. It provides available modules to the current chunk group. It’s assumed to be loaded before the current chunk group.
Traced
The module not placed in chunk group, but its references are still followed. This is used for NFT, to list all unbundled files that are still needed at runtime (some static assets, or externals and their transitive dependencies).
Fields
mode: TracedModeWhether this reference is an entry point for a traced subgraph.
Implementations
Sourceimpl ChunkingType
impl ChunkingType
pub fn is_inherit_async(&self) -> bool
pub fn is_parallel(&self) -> bool
pub fn is_traced(&self) -> bool
pub fn is_merged(&self) -> bool
pub fn without_inherit_async(&self) -> Self