ChunkingConfig

Struct ChunkingConfig 

pub struct ChunkingConfig {
    pub min_chunk_size: usize,
    pub max_chunk_count_per_group: usize,
    pub max_merge_chunk_size: usize,
    pub generate_component_chunks: bool,
    pub min_component_chunk_size: usize,
    pub style_groups_algorithm: StyleGroupsAlgorithm,
    pub first_page_load_priority: Option<u32>,
    pub priority_boost_percent: Option<u32>,
    pub request_cost: Option<u64>,
    pub placeholder_for_future_extensions: (),
}

Fields

min_chunk_size: usize

Try to avoid creating more than 1 chunk smaller than this size. It merges multiple small chunks into bigger ones to avoid that.

max_chunk_count_per_group: usize

Try to avoid creating more than this number of chunks per group. It merges multiple chunks into bigger ones to avoid that.

max_merge_chunk_size: usize

Never merges chunks bigger than this size with other chunks. This makes sure that code in big chunks is not duplicated in multiple chunks.

generate_component_chunks: bool

When enabled, a merged chunk also emits its constituent component chunks (referenced, loaded on demand) so the runtime can fetch an individual component chunk instead of the whole merged chunk when it is already cached.

min_component_chunk_size: usize

Minimum size for a component chunk to be emitted on its own when generate_component_chunks is enabled. Component chunks smaller than this are folded into a single remainder component chunk.

style_groups_algorithm: StyleGroupsAlgorithm

Selects the algorithm used to compute crate::module_graph::style_groups::StyleGroups. Only consulted for the CSS chunk type.

first_page_load_priority: Option<u32>

First-page-load priority as an integer percentage (0..=100), or None to use the default. Used by the production chunker’s merge heuristics.

priority_boost_percent: Option<u32>

Priority boost as an integer percentage (e.g. 150 for a 1.5x boost), or None to use the default. Used by the production chunker’s merge heuristics.

request_cost: Option<u64>

Estimated request cost in bytes, or None to use the default. Used by the production chunker’s merge heuristics.

placeholder_for_future_extensions: ()