pub trait ChunkingContextExt {
// Required methods
fn root_chunk_group(
self: Vc<Self>,
ident: Vc<AssetIdent>,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
) -> Vc<ChunkGroupResult>
where Self: Send;
fn root_chunk_group_assets(
self: Vc<Self>,
ident: Vc<AssetIdent>,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
) -> Vc<OutputAssetsWithReferenced>
where Self: Send;
fn evaluated_chunk_group_assets(
self: Vc<Self>,
ident: Vc<AssetIdent>,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
extra_chunks: Vc<OutputAssets>,
availability_info: AvailabilityInfo,
) -> Vc<OutputAssetsWithReferenced>
where Self: Send;
fn entry_chunk_group_asset(
self: Vc<Self>,
path: FileSystemPath,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
extra_chunks: Vc<OutputAssets>,
extra_referenced_assets: Vc<OutputAssets>,
availability_info: AvailabilityInfo,
) -> Vc<Box<dyn OutputAsset>>
where Self: Send;
fn root_entry_chunk_group(
self: Vc<Self>,
path: FileSystemPath,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
extra_chunks: Vc<OutputAssets>,
extra_referenced_assets: Vc<OutputAssets>,
) -> Vc<EntryChunkGroupResult>
where Self: Send;
fn root_entry_chunk_group_asset(
self: Vc<Self>,
path: FileSystemPath,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
extra_chunks: Vc<OutputAssets>,
extra_referenced_assets: Vc<OutputAssets>,
) -> Vc<Box<dyn OutputAsset>>
where Self: Send;
fn chunk_group_assets(
self: Vc<Self>,
ident: Vc<AssetIdent>,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
availability_info: AvailabilityInfo,
) -> Vc<OutputAssetsWithReferenced>
where Self: Send;
fn relative_path_from_chunk_root_to_project_root(
self: Vc<Self>,
) -> Vc<RcStr>
where Self: Send;
}Required Methods
fn root_chunk_group(
self: Vc<Self>,
ident: Vc<AssetIdent>,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
) -> Vc<ChunkGroupResult>where
Self: Send,
fn root_chunk_group_assets(
self: Vc<Self>,
ident: Vc<AssetIdent>,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
) -> Vc<OutputAssetsWithReferenced>where
Self: Send,
fn evaluated_chunk_group_assets(
self: Vc<Self>,
ident: Vc<AssetIdent>,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
extra_chunks: Vc<OutputAssets>,
availability_info: AvailabilityInfo,
) -> Vc<OutputAssetsWithReferenced>where
Self: Send,
fn entry_chunk_group_asset(
self: Vc<Self>,
path: FileSystemPath,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
extra_chunks: Vc<OutputAssets>,
extra_referenced_assets: Vc<OutputAssets>,
availability_info: AvailabilityInfo,
) -> Vc<Box<dyn OutputAsset>>where
Self: Send,
fn root_entry_chunk_group(
self: Vc<Self>,
path: FileSystemPath,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
extra_chunks: Vc<OutputAssets>,
extra_referenced_assets: Vc<OutputAssets>,
) -> Vc<EntryChunkGroupResult>where
Self: Send,
fn root_entry_chunk_group_asset(
self: Vc<Self>,
path: FileSystemPath,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
extra_chunks: Vc<OutputAssets>,
extra_referenced_assets: Vc<OutputAssets>,
) -> Vc<Box<dyn OutputAsset>>where
Self: Send,
fn chunk_group_assets(
self: Vc<Self>,
ident: Vc<AssetIdent>,
chunk_group: ChunkGroup,
module_graph: Vc<ModuleGraph>,
availability_info: AvailabilityInfo,
) -> Vc<OutputAssetsWithReferenced>where
Self: Send,
Sourcefn relative_path_from_chunk_root_to_project_root(self: Vc<Self>) -> Vc<RcStr>where
Self: Send,
fn relative_path_from_chunk_root_to_project_root(self: Vc<Self>) -> Vc<RcStr>where
Self: Send,
Computes the relative path from the chunk output root to the project root.
This is used to compute relative paths for source maps in certain configurations.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.