pub trait Module:
Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required methods
fn ident(self: Vc<Self>) -> Vc<AssetIdent>
where Self: Sized;
fn source(self: Vc<Self>) -> Vc<OptionSource>
where Self: Sized;
fn side_effects(self: Vc<Self>) -> Vc<ModuleSideEffects>
where Self: Sized;
// Provided methods
fn ident_string(self: Vc<Self>) -> Vc<RcStr>
where Self: Sized { ... }
fn references(self: Vc<Self>) -> Vc<ModuleReferences>
where Self: Sized { ... }
fn is_self_async(self: Vc<Self>) -> Vc<bool>
where Self: Sized { ... }
}Expand description
A module. This usually represents parsed source code, which has references to other modules.
For documentation about where this is used and how it fits into the rest of Turbopack, see
crate::_layers.
Required Methods
Sourcefn side_effects(self: Vc<Self>) -> Vc<ModuleSideEffects>where
Self: Sized,
fn side_effects(self: Vc<Self>) -> Vc<ModuleSideEffects>where
Self: Sized,
Returns true if the module is marked as free of side effects in
package.json or by other means.
Provided Methods
Sourcefn references(self: Vc<Self>) -> Vc<ModuleReferences>where
Self: Sized,
fn references(self: Vc<Self>) -> Vc<ModuleReferences>where
Self: Sized,
Other Modules or OutputAssets referenced from this Module.