pub struct ModuleGraph { /* private fields */ }Expand description
The ReadRef version of ModuleGraphBase. This is better for eventual consistency, as the graphs aren’t awaited multiple times within the same task.
Implementations
Sourceimpl ModuleGraph
impl ModuleGraph
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
ResolvedVc.
Cell is selected based on the value type and call order of cell.
Sourceimpl ModuleGraph
impl ModuleGraph
pub fn from_single_graph( graph: OperationVc<SingleModuleGraph>, ) -> OperationVc<Self>
pub fn from_graphs( graphs: Vec<OperationVc<SingleModuleGraph>>, ) -> OperationVc<Self>
Sourcepub fn from_single_graph_without_unused_references(
graph: OperationVc<SingleModuleGraph>,
binding_usage: OperationVc<BindingUsageInfo>,
) -> OperationVc<Self>
pub fn from_single_graph_without_unused_references( graph: OperationVc<SingleModuleGraph>, binding_usage: OperationVc<BindingUsageInfo>, ) -> OperationVc<Self>
Analyze the module graph and remove unused references (by determining the used exports and removing unused imports).
In particular, this removes ModuleReference-s that list only unused exports in the
import_usage()
Sourcepub fn from_graphs_without_unused_references(
graphs: Vec<OperationVc<SingleModuleGraph>>,
binding_usage: OperationVc<BindingUsageInfo>,
) -> OperationVc<Self>
pub fn from_graphs_without_unused_references( graphs: Vec<OperationVc<SingleModuleGraph>>, binding_usage: OperationVc<BindingUsageInfo>, ) -> OperationVc<Self>
Analyze the module graph and remove unused references (by determining the used exports and removing unused imports).
In particular, this removes ModuleReference-s that list only unused exports in the
import_usage()
pub fn chunk_group_info(self: Vc<Self>) -> Vc<ChunkGroupInfo>
pub fn merged_modules(self: Vc<Self>) -> Vc<MergedModuleInfo>
pub fn module_batches( self: Vc<Self>, config: Vc<BatchingConfig>, ) -> Vc<ModuleBatchesGraph>
pub fn style_groups( self: Vc<Self>, chunking_context: Vc<Box<dyn ChunkingContext>>, config: StyleGroupsConfig, ) -> Vc<StyleGroups>
pub fn async_module_info(self: Vc<Self>) -> Vc<AsyncModulesInfo>
pub fn referenced_async_modules( self: Vc<Self>, module: Vc<Box<dyn Module>>, ) -> Vc<AsyncModuleInfo>
Sourcepub fn iter_graphs(self: Vc<Self>) -> Vc<ModuleGraphLayers>
pub fn iter_graphs(self: Vc<Self>) -> Vc<ModuleGraphLayers>
Returns the underlying graphs as a list, to be used for individual graph traversals.
Methods from Deref<Target = ModuleGraphSnapshot>
pub fn entries(&self) -> impl Iterator<Item = ChunkGroupEntry> + '_
pub fn enumerate_nodes( &self, ) -> impl Iterator<Item = (NodeIndex, &SingleModuleGraphNode)> + '_
pub fn iter_nodes( &self, ) -> impl Iterator<Item = ResolvedVc<Box<dyn Module>>> + '_
Sourcepub async fn get_ids(
&self,
) -> Result<FxHashMap<ResolvedVc<Box<dyn Module>>, ReadRef<RcStr>>>
pub async fn get_ids( &self, ) -> Result<FxHashMap<ResolvedVc<Box<dyn Module>>, ReadRef<RcStr>>>
Returns a map of all modules in the graphs to their identifiers. This is primarily useful for debugging.
Sourcepub fn traverse_nodes_dfs<S>(
&self,
entries: impl IntoIterator<Item = ResolvedVc<Box<dyn Module>>>,
state: &mut S,
visit_preorder: impl Fn(ResolvedVc<Box<dyn Module>>, &mut S) -> Result<GraphTraversalAction>,
visit_postorder: impl FnMut(ResolvedVc<Box<dyn Module>>, &mut S) -> Result<()>,
) -> Result<()>
pub fn traverse_nodes_dfs<S>( &self, entries: impl IntoIterator<Item = ResolvedVc<Box<dyn Module>>>, state: &mut S, visit_preorder: impl Fn(ResolvedVc<Box<dyn Module>>, &mut S) -> Result<GraphTraversalAction>, visit_postorder: impl FnMut(ResolvedVc<Box<dyn Module>>, &mut S) -> Result<()>, ) -> Result<()>
Traverses all reachable nodes exactly once and calls the visitor.
entries- The entry modules to start the traversal fromstatemutable state to be shared across the visitorsvisit_preorder- Called before visiting the children of a node.- Receives the module and the
state - Can return GraphTraversalActions to control the traversal
- Receives the module and the
visit_postorder- Called after visiting children of a node.
Sourcepub fn traverse_edges_bfs(
&self,
entries: impl IntoIterator<Item = ResolvedVc<Box<dyn Module>>>,
visitor: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>) -> Result<GraphTraversalAction>,
) -> Result<()>
pub fn traverse_edges_bfs( &self, entries: impl IntoIterator<Item = ResolvedVc<Box<dyn Module>>>, visitor: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>) -> Result<GraphTraversalAction>, ) -> Result<()>
Traverses all reachable edges exactly once and calls the visitor with the edge source and target.
This means that target nodes can be revisited (once per incoming edge).
entry- The entry module to start the traversal fromvisitor- Called before visiting the children of a node.- Receives (originating &SingleModuleGraphNode, edge &ChunkingType), target &SingleModuleGraphNode, state &S
- Can return GraphTraversalActions to control the traversal
Sourcepub fn traverse_edges_unordered(
&self,
visitor: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>) -> Result<()>,
) -> Result<()>
pub fn traverse_edges_unordered( &self, visitor: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>) -> Result<()>, ) -> Result<()>
Traverses all edges exactly once (in an unspecified order) and calls the visitor with the edge source and target.
This means that target nodes can be revisited (once per incoming edge).
visitor- Called before visiting the children of a node.- Receives (originating &SingleModuleGraphNode, edge &ChunkingType), target &SingleModuleGraphNode
Sourcepub fn traverse_edges_dfs<S>(
&self,
entries: impl IntoIterator<Item = ResolvedVc<Box<dyn Module>>>,
state: &mut S,
visit_preorder: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>, &mut S) -> Result<GraphTraversalAction>,
visit_postorder: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>, &mut S) -> Result<()>,
) -> Result<()>
pub fn traverse_edges_dfs<S>( &self, entries: impl IntoIterator<Item = ResolvedVc<Box<dyn Module>>>, state: &mut S, visit_preorder: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>, &mut S) -> Result<GraphTraversalAction>, visit_postorder: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>, &mut S) -> Result<()>, ) -> Result<()>
Traverses all reachable edges in dfs order. The preorder visitor can be used to forward state down the graph, and to skip subgraphs
Use this to collect modules in evaluation order.
Target nodes can be revisited (once per incoming edge) in the preorder_visitor, in the post order visitor they are visited exactly once with the first edge they were discovered with. Edges are traversed in normal order, so should correspond to reference order.
entries- The entry modules to start the traversal fromstate- The state to be passed to the visitorsvisit_preorder- Called before visiting the children of a node.- Receives: (originating &SingleModuleGraphNode, edge &ChunkingType), target &SingleModuleGraphNode, state &S
- Can return GraphTraversalActions to control the traversal
visit_postorder- Called after visiting the children of a node. Return- Receives: (originating &SingleModuleGraphNode, edge &ChunkingType), target &SingleModuleGraphNode, state &S
Sourcepub fn traverse_edges_reverse_dfs<S>(
&self,
entries: impl IntoIterator<Item = ResolvedVc<Box<dyn Module>>>,
state: &mut S,
visit_preorder: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>, &mut S) -> Result<GraphTraversalAction>,
visit_postorder: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>, &mut S) -> Result<()>,
) -> Result<()>
pub fn traverse_edges_reverse_dfs<S>( &self, entries: impl IntoIterator<Item = ResolvedVc<Box<dyn Module>>>, state: &mut S, visit_preorder: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>, &mut S) -> Result<GraphTraversalAction>, visit_postorder: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData)>, ResolvedVc<Box<dyn Module>>, &mut S) -> Result<()>, ) -> Result<()>
Traverses all reachable edges in dfs order over the reversed graph. The preorder visitor can be used to forward state up the graph, and to skip subgraphs
Target nodes can be revisited (once per incoming edge) in the preorder_visitor, in the post order visitor they are visited exactly once with the first edge they were discovered with. Edges are traversed in normal order, so should correspond to reference order.
entries- The entry modules to start the traversal fromstate- The state to be passed to the visitorsvisit_preorder- Called before visiting the children of a node.- Receives: (originating &SingleModuleGraphNode, edge &ChunkingType), target &SingleModuleGraphNode, state &S
- Can return GraphTraversalActions to control the traversal
visit_postorder- Called after visiting the parents of a node. Return- Receives: (originating &SingleModuleGraphNode, edge &ChunkingType), target &SingleModuleGraphNode, state &S
Sourcepub fn traverse_cycles(
&self,
edge_filter: impl Fn(&RefData) -> bool,
visit_cycle: impl FnMut(&[&ResolvedVc<Box<dyn Module>>]) -> Result<()>,
) -> Result<()>
pub fn traverse_cycles( &self, edge_filter: impl Fn(&RefData) -> bool, visit_cycle: impl FnMut(&[&ResolvedVc<Box<dyn Module>>]) -> Result<()>, ) -> Result<()>
Traverse all cycles in the graph (where the edge filter returns true for the whole cycle) and call the visitor with the nodes in the cycle. Notably, module self-references are also treated as cycles.
Sourcepub fn traverse_edges_fixed_point_with_priority<S, P: Ord>(
&self,
entries: impl IntoIterator<Item = (ResolvedVc<Box<dyn Module>>, P)>,
state: &mut S,
visit: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData, GraphEdgeIndex)>, ResolvedVc<Box<dyn Module>>, &mut S) -> Result<GraphTraversalAction>,
priority: impl Fn(ResolvedVc<Box<dyn Module>>, &mut S) -> Result<P>,
) -> Result<usize>
pub fn traverse_edges_fixed_point_with_priority<S, P: Ord>( &self, entries: impl IntoIterator<Item = (ResolvedVc<Box<dyn Module>>, P)>, state: &mut S, visit: impl FnMut(Option<(ResolvedVc<Box<dyn Module>>, &RefData, GraphEdgeIndex)>, ResolvedVc<Box<dyn Module>>, &mut S) -> Result<GraphTraversalAction>, priority: impl Fn(ResolvedVc<Box<dyn Module>>, &mut S) -> Result<P>, ) -> Result<usize>
Traverses all reachable nodes and also continue revisiting them as long the visitor returns GraphTraversalAction::Continue. The visitor is responsible for the runtime complexity and eventual termination of the traversal. This corresponds to computing a fixed point state for the graph.
Nodes are (re)visited according to the returned priority of the node, prioritizing high values. This priority is intended to be used a heuristic to reduce the number of retraversals.
entries- The entry modules to start the traversal fromstate- The state to be passed to the callbacksvisit- Called for a specific edge- Receives: (originating &SingleModuleGraphNode, edge &ChunkingType), target &SingleModuleGraphNode, state &S
- Return GraphTraversalActions to control the traversal
priority- Called for before visiting the children of a node to determine its priority.- Receives: target &SingleModuleGraphNode, state &S
- Return a priority value for the node
Returns the number of node visits (i.e. higher than the node count if there are retraversals).