pub struct StyleGroups {
pub shared_chunk_items: FxIndexMap<ChunkItemWithAsyncModuleInfo, StyleItemInfo>,
}Expand description
Styling must not be duplicated in the application. The simplest way to achieve this is to put
every styling chunk item into a separate chunk. That works, but isn’t efficient since it would
cause a lot of requests. Instead, multiple chunk items are grouped together and placed in a
single shared chunk. StyleGroups specifies how chunk items are grouped together.
Fields
Per-item info keyed by chunk item.
The loose algorithm only inserts items it actively grouped into shared chunks (everything
else is implicitly emitted as a singleton chunk preserving input order). The graph
algorithm inserts every input item — including singletons — so its result fully determines
the final per-chunk-group ordering through StyleItemInfo::order.
Implementations
Sourceimpl StyleGroups
impl StyleGroups
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
[ResolvedVc][turbo_tasks::ResolvedVc].
Cell is selected based on the value type and call order of cell.