pub enum ModuleResolveResultItem {
Module(ResolvedVc<Box<dyn Module>>),
External {
name: RcStr,
ty: ExternalType,
},
Unknown(ResolvedVc<Box<dyn Source>>),
Ignore,
Error(ResolvedVc<Box<dyn Issue>>),
Empty,
Custom(u8),
Duplicate(usize),
}Variants
Module(ResolvedVc<Box<dyn Module>>)
External
Unknown(ResolvedVc<Box<dyn Source>>)
A module could not be created (according to the rules, e.g. no module type as assigned)
Ignore
Completely ignore this reference.
Error(ResolvedVc<Box<dyn Issue>>)
Emit the given issue, and generate a module which throws that issue’s title at runtime.
Empty
Resolve the reference to an empty module.
Custom(u8)
Duplicate(usize)
A duplicate of an item that appeared earlier in the primary array. The usize is the index of the first occurrence. Most callers should skip this variant.
Bakes duplicate detection into the datastructure to make filtering for uniques trivial which is required by primary_modules.
Implementations
Sourceimpl ModuleResolveResultItem
impl ModuleResolveResultItem
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
[ResolvedVc][turbo_tasks::ResolvedVc].
Cell is selected based on the value type and call order of cell.