pub trait GenerateSourceMap:
Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required method
fn generate_source_map(self: Vc<Self>) -> Vc<FileContent>
where Self: Sized;
// Provided method
fn by_section(self: Vc<Self>, _section: RcStr) -> Vc<FileContent>
where Self: Sized { ... }
}Expand description
Allows callers to generate source maps.
Required Methods
Sourcefn generate_source_map(self: Vc<Self>) -> Vc<FileContent>where
Self: Sized,
fn generate_source_map(self: Vc<Self>) -> Vc<FileContent>where
Self: Sized,
Generates a usable source map, capable of both tracing and stringifying.
Provided Methods
Sourcefn by_section(self: Vc<Self>, _section: RcStr) -> Vc<FileContent>where
Self: Sized,
fn by_section(self: Vc<Self>, _section: RcStr) -> Vc<FileContent>where
Self: Sized,
Returns an individual section of the larger source map, if found.