Version

Trait Version 

pub trait Version:
    Send
    + Sync
    + NonLocalValue
    + ValueDebug {
    // Required method
    fn id(self: Vc<Self>) -> Vc<RcStr>
       where Self: Sized;
}
Describes the current version of an object, and how to update them from an earlier version.

Important: Implementations must not contain instances of [Vc]! This should describe a specific version, and the value of a [Vc] can change due to invalidations or cache eviction.

Required Methods

fn id(self: Vc<Self>) -> Vc<RcStr>
where Self: Sized,

Get a unique identifier of the version as a string. There is no way to convert an id back to its original Version, so the original object needs to be stored somewhere.