pub struct ChunkingConfig {
pub min_chunk_size: usize,
pub max_chunk_count_per_group: usize,
pub max_merge_chunk_size: usize,
pub generate_component_chunks: bool,
pub min_component_chunk_size: usize,
pub style_groups_algorithm: StyleGroupsAlgorithm,
pub first_page_load_priority: Option<u32>,
pub priority_boost_percent: Option<u32>,
pub request_cost: Option<u64>,
pub placeholder_for_future_extensions: (),
}Fields
min_chunk_size: usizeTry to avoid creating more than 1 chunk smaller than this size. It merges multiple small chunks into bigger ones to avoid that.
max_chunk_count_per_group: usizeTry to avoid creating more than this number of chunks per group. It merges multiple chunks into bigger ones to avoid that.
max_merge_chunk_size: usizeNever merges chunks bigger than this size with other chunks. This makes sure that code in big chunks is not duplicated in multiple chunks.
generate_component_chunks: boolWhen enabled, a merged chunk also emits its constituent component chunks (referenced, loaded on demand) so the runtime can fetch an individual component chunk instead of the whole merged chunk when it is already cached.
min_component_chunk_size: usizeMinimum size for a component chunk to be emitted on its own when
generate_component_chunks is enabled. Component chunks smaller than this are folded
into a single remainder component chunk.
style_groups_algorithm: StyleGroupsAlgorithmSelects the algorithm used to compute
crate::module_graph::style_groups::StyleGroups. Only consulted for the CSS chunk
type.
first_page_load_priority: Option<u32>First-page-load priority as an integer percentage (0..=100), or None to use the
default. Used by the production chunker’s merge heuristics.
priority_boost_percent: Option<u32>Priority boost as an integer percentage (e.g. 150 for a 1.5x boost), or None to use the
default. Used by the production chunker’s merge heuristics.
request_cost: Option<u64>Estimated request cost in bytes, or None to use the default. Used by the production
chunker’s merge heuristics.
placeholder_for_future_extensions: ()Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for ChunkingConfig
impl<'__de, __Context> BorrowDecode<'__de, __Context> for ChunkingConfig
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Sourceimpl Clone for ChunkingConfig
impl Clone for ChunkingConfig
Sourcefn clone(&self) -> ChunkingConfig
fn clone(&self) -> ChunkingConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ChunkingConfig
impl Debug for ChunkingConfig
Sourceimpl<__Context> Decode<__Context> for ChunkingConfig
impl<__Context> Decode<__Context> for ChunkingConfig
Sourceimpl Default for ChunkingConfig
impl Default for ChunkingConfig
Sourcefn default() -> ChunkingConfig
fn default() -> ChunkingConfig
Sourceimpl Encode for ChunkingConfig
impl Encode for ChunkingConfig
impl Eq for ChunkingConfig
Sourceimpl Hash for ChunkingConfig
impl Hash for ChunkingConfig
impl NonLocalValue for ChunkingConfig
Sourceimpl PartialEq for ChunkingConfig
impl PartialEq for ChunkingConfig
Sourcefn eq(&self, other: &ChunkingConfig) -> bool
fn eq(&self, other: &ChunkingConfig) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChunkingConfig
Sourceimpl TaskInput for ChunkingConfig
impl TaskInput for ChunkingConfig
Sourcefn is_transient(&self) -> bool
fn is_transient(&self) -> bool
Sourcefn resolve_input(&self) -> impl Future<Output = Result<Self, Error>> + Send
fn resolve_input(&self) -> impl Future<Output = Result<Self, Error>> + Send
Vcs nested inside of this object, cloning the object in
the process. If the input is unresolved (TaskInput::is_resolved) a “local” resolution
task is created that runs this method.Sourceimpl TraceRawVcs for ChunkingConfig
impl TraceRawVcs for ChunkingConfig
fn trace_raw_vcs(&self, __context__: &mut TraceRawVcsContext)
fn get_raw_vcs(&self) -> Vec<RawVc>