pub trait IssueReporter:
Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required method
fn report_issues<'life0, 'async_trait>(
&'life0 self,
issues: ReadRef<PlainIssues>,
source: RawVc,
min_failing_severity: IssueSeverity,
) -> Pin<Box<dyn Future<Output = Result<bool>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Methods
Sourcefn report_issues<'life0, 'async_trait>(
&'life0 self,
issues: ReadRef<PlainIssues>,
source: RawVc,
min_failing_severity: IssueSeverity,
) -> Pin<Box<dyn Future<Output = Result<bool>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn report_issues<'life0, 'async_trait>(
&'life0 self,
issues: ReadRef<PlainIssues>,
source: RawVc,
min_failing_severity: IssueSeverity,
) -> Pin<Box<dyn Future<Output = Result<bool>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Reports already-collected issues to the user (e.g. to stdio). Returns whether fatal (program-ending) issues were present.
This is intentionally not a #[turbo_tasks::function]: it performs no turbo-tasks
reads of its own (the issues are collected ahead of time by [collect_issues]), so it
is safe to call from a top-level task.
Arguments:
issues- The plain issues already collected from the source.source- The rootRawVcfrom which the issues were traced. Can be used by implementers as a dedup key to determine which issues are new. This must be derived from theOperationVcthe issues were collected from.min_failing_severity- The minimum issue severity level considered to fatally end the program.