pub trait IssueReporter:
Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required method
fn report_issues(
self: Vc<Self>,
source: TransientValue<RawVc>,
min_failing_severity: IssueSeverity,
) -> Vc<bool>
where Self: Sized;
}Required Methods
Sourcefn report_issues(
self: Vc<Self>,
source: TransientValue<RawVc>,
min_failing_severity: IssueSeverity,
) -> Vc<bool>where
Self: Sized,
fn report_issues(
self: Vc<Self>,
source: TransientValue<RawVc>,
min_failing_severity: IssueSeverity,
) -> Vc<bool>where
Self: Sized,
Reports issues to the user (e.g. to stdio). Returns whether fatal (program-ending) issues were present.
Arguments:
source- The root [Vc] from which issues are traced. Can be used by implementers to determine which issues are new. This must be derived from the OperationVc so issues can be collected.min_failing_severity- The minimum Vc<IssueSeverity> The minimum issue severity level considered to fatally end the program.