pub trait OutputAsset:
Asset
+ OutputAssetsReference
+ Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required method
fn path(self: Vc<Self>) -> Vc<FileSystemPath>
where Self: Sized;
// Provided method
fn path_string(self: Vc<Self>) -> Vc<RcStr>
where Self: Sized { ... }
}Expand description
An asset that should be outputted, e. g. written to disk or served from a server.
For documentation about where this is used and how it fits into the rest of Turbopack, see
crate::_layers.
Required Methods
Sourcefn path(self: Vc<Self>) -> Vc<FileSystemPath>where
Self: Sized,
fn path(self: Vc<Self>) -> Vc<FileSystemPath>where
Self: Sized,
The identifier of the OutputAsset. It’s expected to be unique and capture all properties of the OutputAsset.
Provided Methods
Sourcefn path_string(self: Vc<Self>) -> Vc<RcStr>where
Self: Sized,
fn path_string(self: Vc<Self>) -> Vc<RcStr>where
Self: Sized,
The identifier of the OutputAsset as string. It’s expected to be unique and capture all properties of the OutputAsset.