pub trait ResolveOrigin:
Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required methods
fn origin_path(&self) -> FileSystemPath;
fn asset_context(&self) -> ResolvedVc<Box<dyn AssetContext>>;
// Provided method
fn resolve_options(&self) -> Vc<ResolveOptions> { ... }
}Expand description
A location where resolving can occur from. It carries some meta information that are needed for resolving from here.
Required Methods
Sourcefn origin_path(&self) -> FileSystemPath
fn origin_path(&self) -> FileSystemPath
The origin path where resolving starts. This is pointing to a file, since that might be needed to infer custom resolving options for that specific file. But usually only the directory is relevant for the real resolving.
Sourcefn asset_context(&self) -> ResolvedVc<Box<dyn AssetContext>>
fn asset_context(&self) -> ResolvedVc<Box<dyn AssetContext>>
The AssetContext that carries the configuration for building that subgraph.
Provided Methods
Sourcefn resolve_options(&self) -> Vc<ResolveOptions>
fn resolve_options(&self) -> Vc<ResolveOptions>
Get the resolve options that apply for this origin.