pub trait AfterResolvePlugin:
Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required methods
fn after_resolve_condition(&self) -> Vc<AfterResolvePluginCondition>;
fn after_resolve(
self: Vc<Self>,
fs_path: FileSystemPath,
lookup_path: FileSystemPath,
reference_type: ReferenceType,
request: Vc<Request>,
) -> Vc<ResolveResultOption>
where Self: Sized;
}Required Methods
Sourcefn after_resolve_condition(&self) -> Vc<AfterResolvePluginCondition>
fn after_resolve_condition(&self) -> Vc<AfterResolvePluginCondition>
A condition which determines if the hooks gets called.
Sourcefn after_resolve(
self: Vc<Self>,
fs_path: FileSystemPath,
lookup_path: FileSystemPath,
reference_type: ReferenceType,
request: Vc<Request>,
) -> Vc<ResolveResultOption>where
Self: Sized,
fn after_resolve(
self: Vc<Self>,
fs_path: FileSystemPath,
lookup_path: FileSystemPath,
reference_type: ReferenceType,
request: Vc<Request>,
) -> Vc<ResolveResultOption>where
Self: Sized,
This hook gets called when a full filepath has been resolved and the condition matches. If a value is returned it replaces the resolve result.